import dotenv from "dotenv";
import express from "express";
import "reflect-metadata";
const cors = require("cors");

import locationRoutes from "./controller/locationController";
import lpTtnEndDeviceUplinksRoutes from "./controller/lpTtnEndDeviceUplinksController";
import ttnRoutes from "./controller/ttnController";
import ttnGatewayReceptionRoutes from "./controller/ttnGatewayReceptionController";
import wifiLocationRoutes from "./controller/wifiLocationController";
import wifiLocationHistoryRoutes from "./controller/wifiLocationHistoryController";
import wifiScanRoutes from "./controller/wifiScanController";
import metricsRoutes from "./controller/metricsController";

dotenv.config();

const app = express();
const PORT = process.env.PORT || 3000;

app.use(cors());
app.use(express.json());

app.use("/api/lp-ttn-end-device-uplinks", lpTtnEndDeviceUplinksRoutes);
app.use("/api/ttn-gateway-receptions", ttnGatewayReceptionRoutes);
app.use("/api/wifi-location-history", wifiLocationHistoryRoutes);
app.use("/api/wifi-location", wifiLocationRoutes);
app.use("/api/wifi-scans", wifiScanRoutes);
app.use("/api/locations", locationRoutes);
app.use("/api/ttn", ttnRoutes);
app.use("/api/metrics", metricsRoutes);

app.listen(PORT, () => {
  console.log(`🚀 Server runs here: http://localhost:${PORT}`);
});
