import { Attributes, FindOptions } from "sequelize";
import { injectable } from "tsyringe";
import { Location } from "../models/location";

@injectable()
export class LocationRepository {
  public async findAll(options?: FindOptions<Attributes<Location>>) {
    return await Location.findAll(options);
  }

  public async findById(id: string) {
    return await Location.findByPk(id);
  }

  public async create(data: Partial<Location>) {
    return await Location.create(data);
  }

  public async update(id: string, data: Partial<Location>) {
    const location = await this.findById(id);
    if (location) {
      return await location.update(data);
    }
    return null;
  }

  public async delete(id: string) {
    const location = await this.findById(id);
    if (location) {
      await location.destroy();
      return true;
    }
    return false;
  }
}
